@@ -14,7 +14,7 @@ use Filter::signatures;
 use feature 'signatures';
 no warnings 'experimental::signatures';
 
-our $VERSION = '0.25';
+our $VERSION = '0.26';
 
 =head1 NAME
 
@@ -22,9 +22,18 @@ HTTP::Request::CurlParameters - container for a Curl-like HTTP request
 
 =head1 SYNOPSIS
 
+  my $ua = LWP::UserAgent->new;
+  my $params = HTTP::Request::CurlParameters->new(argv => \@ARGV);
+  my $response = $ua->request($params->as_request);
+
 =head1 DESCRIPTION
 
-Objects of this class are mostly created from L<HTTP::Request::FromCurl>.
+Objects of this class are mostly created from L<HTTP::Request::FromCurl>. Most
+likely you want to use that module instead:
+
+  my $ua = LWP::UserAgent->new;
+  my $params = HTTP::Request::FromCurl->new(command_curl => $cmd);
+  my $response = $ua->request($params->as_request);
 
 =head1 METHODS
 
@@ -707,9 +716,8 @@ L<https://perlmonks.org/>.
 
 =head1 BUG TRACKER
 
-Please report bugs in this module via the RT CPAN bug queue at
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=HTTP-Request-FromCurl>
-or via mail to L<filter-signatures-Bugs@rt.cpan.org>.
+Please report bugs in this module via the Github bug queue at
+L<https://github.com/Corion/HTTP-Request-FromCurl/issues>
 
 =head1 AUTHOR
 
@@ -717,7 +725,7 @@ Max Maischein C<corion@cpan.org>
 
 =head1 COPYRIGHT (c)
 
-Copyright 2018-2020 by Max Maischein C<corion@cpan.org>.
+Copyright 2018-2021 by Max Maischein C<corion@cpan.org>.
 
 =head1 LICENSE
 
